@@ -1,4 +1,4 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf-8 -*-
 #
 # Copyright 2002 Ben Escoto <ben@emerose.org>
 # Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
@@ -24,7 +24,10 @@ from future import standard_library
 standard_library.install_aliases()
 
 import sys
-import mock
+try:
+    import unittest.mock as mock
+except ImportError:
+    import mock
 import unittest
 
 import duplicity.backend
